var classtvg_1_1Text =
[
    [ "fill", "classtvg_1_1Text.html#ad0cb7b2ec8d18d7c6d366cc84741682c", null ],
    [ "fill", "classtvg_1_1Text.html#ab82934b0e19f300568f0aaab976e56fa", null ],
    [ "font", "classtvg_1_1Text.html#ae75b2b7eaa5757cfaa6620df127c0416", null ],
    [ "text", "classtvg_1_1Text.html#a9dd4d33d94a639639321538338e9f9f8", null ],
    [ "type", "classtvg_1_1Text.html#a0998d9f221df277cafde4934e3828aa2", null ]
];